@@ -13,7 +13,7 @@ use Data::Structure::Util qw( get_blessed );
 
 use base qw( Class::Accessor::Chained );
 
-our $VERSION = "0.94";
+our $VERSION = 0.95;
 our $AUTOLOAD;
 
 exception EO::Error::New;
@@ -83,6 +83,7 @@ sub clone {
   my $self = shift;
   my $clone = Clone::clone( $self );
   my $objs  = get_blessed( $clone );
+  ## ensure we regenerate the oids.
   foreach my $object (@$objs) {
     if ($object->isa('EO')) {
       $object->set_oid( $object->generate_oid() );
@@ -91,6 +92,12 @@ sub clone {
   $clone;
 }
 
+sub as_string {
+  my $self = shift;
+  my $class = ref($self);
+  return "I am an '$class' object";
+}
+
 sub DESTROY { 1; }
 
 1;
@@ -174,6 +181,11 @@ is the only method that should be used for cloning in order to preserve
 id's.  The clone method guarantees that all objects contained within
 an object that respond true to ->isa('EO') will have their id's regenerated.
 
+=item as_string()
+
+Provides stringification.  Note -- this is not currently overloaded, but
+probably should be considered.
+
 =back
 
 =head1 ATTRIBUTES
